@@ -1,9 +1,8 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_PARSE_UTIL_H_
 # define _GNM_PARSE_UTIL_H_
 
-#include "gnumeric.h"
-#include "libgnumeric.h"
+#include <gnumeric.h>
+#include <libgnumeric.h>
 
 G_BEGIN_DECLS
 
@@ -13,7 +12,7 @@ char const *col_parse (char const *str, GnmSheetSize const *ss,
 		       int *res, unsigned char *relative);
 
 char const *row_name  (int row);
-char const *rows_name (int start_row, int end_col);
+char const *rows_name (int start_row, int end_row);
 char const *row_parse (char const *str, GnmSheetSize const *ss,
 		       int *res, unsigned char *relative);
 
@@ -28,7 +27,7 @@ char const *cellref_parse	(GnmCellRef *out, GnmSheetSize const *ss,
 
 void        rangeref_as_string  (GnmConventionsOut *out,
 				 GnmRangeRef const *ref);
-char const *rangeref_parse	(GnmRangeRef *res, char const *in,
+char const *rangeref_parse	(GnmRangeRef *res, char const *start,
 				 GnmParsePos const *pp,
 				 GnmConventions const *convs);
 				 /* GError **err); */
@@ -119,6 +118,8 @@ struct _GnmConventions {
 
 	/* What character denotes range intersection?  */
 	gunichar intersection_char;
+	/* What character denotes range union?  */
+	gunichar union_char;
 
 	/* What characters are range separators?  */
 	gboolean range_sep_colon;  /* A1:B2 */
@@ -206,7 +207,7 @@ GType           gnm_conventions_get_type (void);
 GnmConventions *gnm_conventions_new	 (void);
 GnmConventions *gnm_conventions_new_full (unsigned size);
 
-GnmConventions *gnm_conventions_ref	 (GnmConventions *c);
+GnmConventions *gnm_conventions_ref	 (GnmConventions const *c);
 void		gnm_conventions_unref	 (GnmConventions *c);
 
 
@@ -236,7 +237,7 @@ void	    parse_text_value_or_expr (GnmParsePos const *pos,
 				      GnmValue **val,
 				      GnmExprTop const **texpr);
 
-GString	*gnm_expr_conv_quote (GnmConventions const *conv, char const *str);
+GString	*gnm_expr_conv_quote (GnmConventions const *convs, char const *str);
 
 G_END_DECLS
 
